# Toy Robot
> A toy robot, toy application where the toy robot doesn't fall off the toy table


## Install

`pip install -e .`

## Documentation

For documentation, refer [here](https://amaarora.github.io/toyrobot/).

## Run 

To run the project in command line, 
```python
python main.py --cmd_file_path <path_to_txt_file>
```

As an example:

`python main.py --cmd_file_path ./example1.txt`

```
ToyRobot facing new direction: WEST
ToyRobot facing new direction: NORTH
New position on table: (0, 1)
ToyRobot, currently at (0, 1) and facing NORTH!
```
